# Sentry-DingDing

Fork `https://github.com/anshengme/sentry-dingding`

Fix  `Sentry 10 or the same error`

[sentry-dingding issues](https://github.com/anshengme/sentry-dingding/issues/22)

```
'Event' object has no attribute 'id' 
```

## 安装

```
# requirement.txt

sentry-10-dingding
```

docker-compose 安装的直接改成这个插件包就好了，如果帮你解决了问题，麻烦给个小星星.

